[jboss-cvs] JBossAS SVN: r77505 - trunk/server/src/main/org/jboss/ejb/plugins.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Tue Aug 26 15:53:04 EDT 2008


Author: bstansberry at jboss.com
Date: 2008-08-26 15:53:04 -0400 (Tue, 26 Aug 2008)
New Revision: 77505

Modified:
   trunk/server/src/main/org/jboss/ejb/plugins/ProxyFactoryFinderInterceptor.java
Log:
[JBAS-4192] Clear the ProxyFactory from ThreadLocal

Modified: trunk/server/src/main/org/jboss/ejb/plugins/ProxyFactoryFinderInterceptor.java
===================================================================
--- trunk/server/src/main/org/jboss/ejb/plugins/ProxyFactoryFinderInterceptor.java	2008-08-26 19:26:38 UTC (rev 77504)
+++ trunk/server/src/main/org/jboss/ejb/plugins/ProxyFactoryFinderInterceptor.java	2008-08-26 19:53:04 UTC (rev 77505)
@@ -109,8 +109,8 @@
       finally
       {
          ENCThreadLocalKey.setKey(oldInvokerBinding);
-         // TODO: we should probably clear the thread local, i.e.
-         //container.setProxyFactory(null);
+         // JBAS-4192 clear the container's thread local
+         container.setProxyFactory(null); 
       }
 
       return value;
@@ -140,8 +140,8 @@
       finally
       {
          ENCThreadLocalKey.setKey(oldInvokerBinding);
-         // TODO: we should probably clear the thread local, i.e.
-         //container.setProxyFactory(null); 
+         // JBAS-4192 clear the container's thread local
+         container.setProxyFactory(null); 
       }
 
       return value;




More information about the jboss-cvs-commits mailing list